@@ -26,6 +26,7 @@ class Menu(MPTTModel):
         verbose_name = _('Menu')
         verbose_name_plural = _('Menus')
         app_label = _('Content')
+        db_table = 'django_zen_menu'
 
     def __unicode__(self):
         return self.name
@@ -54,6 +55,7 @@ class Page(models.Model):
         verbose_name = _('Page')
         verbose_name_plural = _('Pages')
         app_label = _('Content')
+        db_table = 'django_zen_page'
 
     def __unicode__(self):
         return self.url
